..
      Copyright 2010-2011 United States Government as represented by the
      Administrator of the National Aeronautics and Space Administration.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Contributor/Developer Guide
===========================

In this section you will find information helpful for contributing to manila.


Basic Information
-----------------

.. toctree::
   :maxdepth: 3

   contributing


Programming HowTos and Tutorials
--------------------------------
.. toctree::
    :maxdepth: 3

    development.environment
    development-environment-devstack
    apache-httpd
    unit_tests
    tempest_tests
    addmethod.openstackapi
    documenting_your_work
    adding_release_notes
    commit_message_tags
    guru_meditation_report
    user_messages
    ganesha

Background Concepts for manila
------------------------------
.. toctree::
   :maxdepth: 3

   architecture
   threading
   i18n
   rpc
   driver_requirements
   pool-aware-manila-scheduler

Other Resources
---------------
.. toctree::
   :maxdepth: 3

   launchpad
   gerrit
   manila-review-policy
   project-team-lead

API Reference
-------------
.. toctree::
   :maxdepth: 3

   Manila API v2 Reference <https://docs.openstack.org/api-ref/shared-file-system/>
   api_microversion_dev
   api_microversion_history
   experimental_apis

Module Reference
----------------
.. toctree::
   :maxdepth: 3

   intro
   services
   database
   share
   share_hooks
   auth
   scheduler
   fakes
   manila
   share_replication
   driver_filter_goodness_weigher
   share_migration
   share_server_migration

.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`search`

